http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
index 346978c..610b0c8 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridEmbeddedFuture.java
@@ -28,7 +28,7 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
     private static final long serialVersionUID = 0L;
 
     /** Embedded future to wait for. */
-    private IgniteFuture<B> embedded;
+    private InternalFuture<B> embedded;
 
     /**
      * Empty constructor required by {@link Externalizable}.
@@ -42,7 +42,7 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
      * @param embedded Embedded future.
      * @param c Closure to execute upon completion of embedded future.
      */
-    public GridEmbeddedFuture(GridKernalContext ctx, IgniteFuture<B> embedded, 
final IgniteBiClosure<B, Exception, A> c) {
+    public GridEmbeddedFuture(GridKernalContext ctx, InternalFuture<B> 
embedded, final IgniteBiClosure<B, Exception, A> c) {
         super(ctx);
 
         assert embedded != null;
@@ -52,7 +52,7 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
 
         embedded.listenAsync(new AL1() {
             @SuppressWarnings({"ErrorNotRethrown", "CatchGenericClass"})
-            @Override public void applyx(IgniteFuture<B> embedded) {
+            @Override public void applyx(InternalFuture<B> embedded) {
                 try {
                     onDone(c.apply(embedded.get(), null));
                 }
@@ -76,7 +76,7 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
      * @param c Closure which runs upon completion of embedded closure and 
which returns another future.
      * @param ctx Context.
      */
-    public GridEmbeddedFuture(boolean syncNotify, IgniteFuture<B> embedded, 
IgniteBiClosure<B, Exception, IgniteFuture<A>> c,
+    public GridEmbeddedFuture(boolean syncNotify, InternalFuture<B> embedded, 
IgniteBiClosure<B, Exception, InternalFuture<A>> c,
         GridKernalContext ctx) {
         this(embedded, c, ctx);
 
@@ -90,7 +90,7 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
      * @param embedded Closure.
      * @param c Closure which runs upon completion of embedded closure and 
which returns another future.
      */
-    public GridEmbeddedFuture(IgniteFuture<B> embedded, final 
IgniteBiClosure<B, Exception, IgniteFuture<A>> c,
+    public GridEmbeddedFuture(InternalFuture<B> embedded, final 
IgniteBiClosure<B, Exception, InternalFuture<A>> c,
         GridKernalContext ctx) {
         super(ctx);
 
@@ -100,9 +100,9 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
         this.embedded = embedded;
 
         embedded.listenAsync(new AL1() {
-            @Override public void applyx(IgniteFuture<B> embedded) {
+            @Override public void applyx(InternalFuture<B> embedded) {
                 try {
-                    IgniteFuture<A> next = c.apply(embedded.get(), null);
+                    InternalFuture<A> next = c.apply(embedded.get(), null);
 
                     if (next == null) {
                         onDone();
@@ -111,7 +111,7 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
                     }
 
                     next.listenAsync(new AL2() {
-                        @Override public void applyx(IgniteFuture<A> next) {
+                        @Override public void applyx(InternalFuture<A> next) {
                             try {
                                 onDone(next.get());
                             }
@@ -156,8 +156,8 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
      * @param c1 Closure which runs upon completion of embedded future and 
which returns another future.
      * @param c2 Closure will runs upon completion of future returned by 
{@code c1} closure.
      */
-    public GridEmbeddedFuture(GridKernalContext ctx, IgniteFuture<B> embedded, 
final IgniteBiClosure<B, Exception,
-        IgniteFuture<A>> c1, final IgniteBiClosure<A, Exception, A> c2) {
+    public GridEmbeddedFuture(GridKernalContext ctx, InternalFuture<B> 
embedded, final IgniteBiClosure<B, Exception,
+        InternalFuture<A>> c1, final IgniteBiClosure<A, Exception, A> c2) {
         super(ctx);
 
         assert embedded != null;
@@ -167,9 +167,9 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
         this.embedded = embedded;
 
         embedded.listenAsync(new AL1() {
-            @Override public void applyx(IgniteFuture<B> embedded) {
+            @Override public void applyx(InternalFuture<B> embedded) {
                 try {
-                    IgniteFuture<A> next = c1.apply(embedded.get(), null);
+                    InternalFuture<A> next = c1.apply(embedded.get(), null);
 
                     if (next == null) {
                         onDone();
@@ -178,7 +178,7 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
                     }
 
                     next.listenAsync(new AL2() {
-                        @Override public void applyx(IgniteFuture<A> next) {
+                        @Override public void applyx(InternalFuture<A> next) {
                             try {
                                 onDone(c2.apply(next.get(), null));
                             }
@@ -251,12 +251,12 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
     /**
      * Make sure that listener does not throw exceptions.
      */
-    private abstract class AsyncListener1 implements 
IgniteInClosure<IgniteFuture<B>> {
+    private abstract class AsyncListener1 implements 
IgniteInClosure<InternalFuture<B>> {
         /** */
         private static final long serialVersionUID = 0L;
 
         /** {@inheritDoc} */
-        @Override public final void apply(IgniteFuture<B> f) {
+        @Override public final void apply(InternalFuture<B> f) {
             try {
                 applyx(f);
             }
@@ -277,18 +277,18 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
          * @param f Future.
          * @throws Exception In case of error.
          */
-        protected abstract void applyx(IgniteFuture<B> f) throws Exception;
+        protected abstract void applyx(InternalFuture<B> f) throws Exception;
     }
 
     /**
      * Make sure that listener does not throw exceptions.
      */
-    private abstract class AsyncListener2 implements 
IgniteInClosure<IgniteFuture<A>> {
+    private abstract class AsyncListener2 implements 
IgniteInClosure<InternalFuture<A>> {
         /** */
         private static final long serialVersionUID = 0L;
 
         /** {@inheritDoc} */
-        @Override public final void apply(IgniteFuture<A> f) {
+        @Override public final void apply(InternalFuture<A> f) {
             try {
                 applyx(f);
             }
@@ -309,6 +309,6 @@ public class GridEmbeddedFuture<A, B> extends 
GridFutureAdapter<A> {
          * @param f Future.
          * @throws Exception In case of error.
          */
-        protected abstract void applyx(IgniteFuture<A> f) throws Exception;
+        protected abstract void applyx(InternalFuture<A> f) throws Exception;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
index 5f98641..6cfbcc4 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFuture.java
@@ -11,7 +11,6 @@ package org.gridgain.grid.util.future;
 
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
@@ -24,7 +23,7 @@ import static org.apache.ignite.IgniteSystemProperties.*;
 /**
  * Future that is completed at creation time.
  */
-public class GridFinishedFuture<T> implements IgniteFuture<T>, Externalizable {
+public class GridFinishedFuture<T> implements InternalFuture<T>, 
Externalizable {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -159,7 +158,7 @@ public class GridFinishedFuture<T> implements 
IgniteFuture<T>, Externalizable {
     }
 
     /** {@inheritDoc} */
-    @Override public void listenAsync(final IgniteInClosure<? super 
IgniteFuture<T>> lsnr) {
+    @Override public void listenAsync(final IgniteInClosure<? super 
InternalFuture<T>> lsnr) {
         if (ctx == null)
             throw new IllegalStateException("Cannot attach listener to 
deserialized future (context is null): " + this);
 
@@ -176,12 +175,12 @@ public class GridFinishedFuture<T> implements 
IgniteFuture<T>, Externalizable {
     }
 
     /** {@inheritDoc} */
-    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super 
IgniteFuture<T>>... lsnr) {
+    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super 
InternalFuture<T>>... lsnr) {
         // No-op.
     }
 
     /** {@inheritDoc} */
-    @Override public <R> IgniteFuture<R> chain(final IgniteClosure<? super 
IgniteFuture<T>, R> doneCb) {
+    @Override public <R> InternalFuture<R> chain(final IgniteClosure<? super 
InternalFuture<T>, R> doneCb) {
         GridFutureAdapter<R> fut = new GridFutureAdapter<R>(ctx, syncNotify) {
             @Override public String toString() {
                 return "ChainFuture[orig=" + GridFinishedFuture.this + ", 
doneCb=" + doneCb + ']';

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
index 663cf87..3698fbc 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFinishedFutureEx.java
@@ -23,7 +23,7 @@ import java.util.concurrent.*;
  * {@link GridFinishedFuture} as it does not take context as a parameter and
  * performs notifications in the same thread.
  */
-public class GridFinishedFutureEx<T> implements IgniteFuture<T>, 
Externalizable {
+public class GridFinishedFutureEx<T> implements InternalFuture<T>, 
Externalizable {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -135,7 +135,7 @@ public class GridFinishedFutureEx<T> implements 
IgniteFuture<T>, Externalizable
     }
 
     /** {@inheritDoc} */
-    @Override public <R> IgniteFuture<R> chain(IgniteClosure<? super 
IgniteFuture<T>, R> doneCb) {
+    @Override public <R> InternalFuture<R> chain(IgniteClosure<? super 
InternalFuture<T>, R> doneCb) {
         try {
             return new GridFinishedFutureEx<>(doneCb.apply(this));
         }
@@ -151,13 +151,13 @@ public class GridFinishedFutureEx<T> implements 
IgniteFuture<T>, Externalizable
 
     /** {@inheritDoc} */
     @SuppressWarnings({"unchecked"})
-    @Override public void listenAsync(IgniteInClosure<? super IgniteFuture<T>> 
lsnr) {
+    @Override public void listenAsync(IgniteInClosure<? super 
InternalFuture<T>> lsnr) {
         if (lsnr != null)
             lsnr.apply(this);
     }
 
     /** {@inheritDoc} */
-    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super 
IgniteFuture<T>>... lsnr) {
+    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super 
InternalFuture<T>>... lsnr) {
         // No-op.
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
index 7d675a7..a0002cf 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapter.java
@@ -28,7 +28,7 @@ import static org.apache.ignite.IgniteSystemProperties.*;
 /**
  * Future adapter.
  */
-public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer 
implements IgniteFuture<R>, Externalizable {
+public class GridFutureAdapter<R> extends AbstractQueuedSynchronizer 
implements InternalFuture<R>, Externalizable {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -70,7 +70,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
     private boolean valid = true;
 
     /** Asynchronous listeners. */
-    private Collection<IgniteInClosure<? super IgniteFuture<R>>> lsnrs;
+    private Collection<IgniteInClosure<? super InternalFuture<R>>> lsnrs;
 
     /** Context. */
     protected GridKernalContext ctx;
@@ -194,7 +194,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
                 acquireSharedInterruptibly(0);
 
             if (getState() == CANCELLED)
-                throw new IgniteFutureCancelledException("Future was 
cancelled: " + this);
+                throw new InternalFutureCancelledException("Future was 
cancelled: " + this);
 
             if (err != null)
                 throw U.cast(err);
@@ -204,7 +204,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
 
-            throw new GridInterruptedException(e);
+            throw new InternalInterruptedException(e);
         }
     }
 
@@ -227,7 +227,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
 
-            throw new GridInterruptedException("Got interrupted while waiting 
for future to complete.", e);
+            throw new InternalInterruptedException("Got interrupted while 
waiting for future to complete.", e);
         }
     }
 
@@ -235,15 +235,15 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
      * @param nanosTimeout Timeout (nanoseconds).
      * @return Result.
      * @throws InterruptedException If interrupted.
-     * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout 
reached before computation completed.
+     * @throws InternalFutureTimeoutException If timeout reached before 
computation completed.
      * @throws IgniteCheckedException If error occurred.
      */
     @Nullable protected R get0(long nanosTimeout) throws InterruptedException, 
IgniteCheckedException {
         if (endTime == 0 && !tryAcquireSharedNanos(0, nanosTimeout))
-            throw new IgniteFutureTimeoutException("Timeout was reached before 
computation completed.");
+            throw new InternalFutureTimeoutException("Timeout was reached 
before computation completed.");
 
         if (getState() == CANCELLED)
-            throw new IgniteFutureCancelledException("Future was cancelled: " 
+ this);
+            throw new InternalFutureCancelledException("Future was cancelled: 
" + this);
 
         if (err != null)
             throw U.cast(err);
@@ -252,7 +252,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public void listenAsync(@Nullable final IgniteInClosure<? super 
IgniteFuture<R>> lsnr) {
+    @Override public void listenAsync(@Nullable final IgniteInClosure<? super 
InternalFuture<R>> lsnr) {
         if (lsnr != null) {
             checkValid();
 
@@ -291,7 +291,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super 
IgniteFuture<R>>... lsnr) {
+    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super 
InternalFuture<R>>... lsnr) {
         synchronized (mux) {
             if (lsnrs == null)
                 return;
@@ -300,10 +300,10 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
                 lsnrs.clear();
             else {
                 // Iterate through the whole list, removing all occurrences, 
if any.
-                for (Iterator<IgniteInClosure<? super IgniteFuture<R>>> it = 
lsnrs.iterator(); it.hasNext();) {
-                    IgniteInClosure<? super IgniteFuture<R>> l1 = it.next();
+                for (Iterator<IgniteInClosure<? super InternalFuture<R>>> it = 
lsnrs.iterator(); it.hasNext();) {
+                    IgniteInClosure<? super InternalFuture<R>> l1 = it.next();
 
-                    for (IgniteInClosure<? super IgniteFuture<R>> l2 : lsnr)
+                    for (IgniteInClosure<? super InternalFuture<R>> l2 : lsnr)
                         // Must be l1.equals(l2), not l2.equals(l1), because 
of the way listeners are added.
                         if (l1.equals(l2))
                             it.remove();
@@ -313,7 +313,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
     }
 
     /** {@inheritDoc} */
-    @Override public <T> IgniteFuture<T> chain(final IgniteClosure<? super 
IgniteFuture<R>, T> doneCb) {
+    @Override public <T> InternalFuture<T> chain(final IgniteClosure<? super 
InternalFuture<R>, T> doneCb) {
         return new ChainFuture<>(ctx, syncNotify, this, doneCb);
     }
 
@@ -321,7 +321,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
      * Notifies all registered listeners.
      */
     private void notifyListeners() {
-        final Collection<IgniteInClosure<? super IgniteFuture<R>>> lsnrs0;
+        final Collection<IgniteInClosure<? super InternalFuture<R>>> lsnrs0;
 
         synchronized (mux) {
             lsnrs0 = lsnrs;
@@ -335,7 +335,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
         assert !lsnrs0.isEmpty();
 
         if (concurNotify) {
-            for (final IgniteInClosure<? super IgniteFuture<R>> lsnr : lsnrs0)
+            for (final IgniteInClosure<? super InternalFuture<R>> lsnr : 
lsnrs0)
                 ctx.closure().runLocalSafe(new GPR() {
                     @Override public void run() {
                         notifyListener(lsnr);
@@ -349,13 +349,13 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
                     @Override public void run() {
                         // Since concurrent notifications are off, we notify
                         // all listeners in one thread.
-                        for (IgniteInClosure<? super IgniteFuture<R>> lsnr : 
lsnrs0)
+                        for (IgniteInClosure<? super InternalFuture<R>> lsnr : 
lsnrs0)
                             notifyListener(lsnr);
                     }
                 }, true);
             }
             else
-                for (IgniteInClosure<? super IgniteFuture<R>> lsnr : lsnrs0)
+                for (IgniteInClosure<? super InternalFuture<R>> lsnr : lsnrs0)
                     notifyListener(lsnr);
         }
     }
@@ -365,7 +365,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
      *
      * @param lsnr Listener.
      */
-    private void notifyListener(IgniteInClosure<? super IgniteFuture<R>> lsnr) 
{
+    private void notifyListener(IgniteInClosure<? super InternalFuture<R>> 
lsnr) {
         assert lsnr != null;
 
         try {
@@ -586,7 +586,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
         private GridFutureAdapter<R> fut;
 
         /** */
-        private IgniteClosure<? super IgniteFuture<R>, T> doneCb;
+        private IgniteClosure<? super InternalFuture<R>, T> doneCb;
 
         /**
          *
@@ -602,7 +602,7 @@ public class GridFutureAdapter<R> extends 
AbstractQueuedSynchronizer implements
          * @param doneCb Closure.
          */
         ChainFuture(GridKernalContext ctx, boolean syncNotify,
-            GridFutureAdapter<R> fut, IgniteClosure<? super IgniteFuture<R>, 
T> doneCb) {
+            GridFutureAdapter<R> fut, IgniteClosure<? super InternalFuture<R>, 
T> doneCb) {
             super(ctx, syncNotify);
 
             this.fut = fut;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
index 84f9eb5..bdca744 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureAdapterEx.java
@@ -27,7 +27,7 @@ import java.util.concurrent.locks.*;
 /**
  * Future adapter without kernal context.
  */
-public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer 
implements IgniteFuture<R>, Externalizable {
+public class GridFutureAdapterEx<R> extends AbstractQueuedSynchronizer 
implements InternalFuture<R>, Externalizable {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -57,7 +57,7 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
     private boolean valid = true;
 
     /** Asynchronous listener. */
-    private final ConcurrentLinkedDeque8<IgniteInClosure<? super 
IgniteFuture<R>>>
+    private final ConcurrentLinkedDeque8<IgniteInClosure<? super 
InternalFuture<R>>>
         lsnrs = new ConcurrentLinkedDeque8<>();
 
     /**
@@ -143,7 +143,7 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
                 acquireSharedInterruptibly(0);
 
             if (getState() == CANCELLED)
-                throw new IgniteFutureCancelledException("Future was 
cancelled: " + this);
+                throw new InternalFutureCancelledException("Future was 
cancelled: " + this);
 
             if (err != null)
                 throw U.cast(err);
@@ -153,7 +153,7 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
 
-            throw new GridInterruptedException(e);
+            throw new InternalInterruptedException(e);
         }
     }
 
@@ -176,7 +176,7 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
 
-            throw new GridInterruptedException("Got interrupted while waiting 
for future to complete.", e);
+            throw new InternalInterruptedException("Got interrupted while 
waiting for future to complete.", e);
         }
     }
 
@@ -184,15 +184,15 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
      * @param nanosTimeout Timeout (nanoseconds).
      * @return Result.
      * @throws InterruptedException If interrupted.
-     * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timeout 
reached before computation completed.
+     * @throws InternalFutureTimeoutException If timeout reached before 
computation completed.
      * @throws IgniteCheckedException If error occurred.
      */
     @Nullable protected R get0(long nanosTimeout) throws InterruptedException, 
IgniteCheckedException {
         if (endTime == 0 && !tryAcquireSharedNanos(0, nanosTimeout))
-            throw new IgniteFutureTimeoutException("Timeout was reached before 
computation completed.");
+            throw new InternalFutureTimeoutException("Timeout was reached 
before computation completed.");
 
         if (getState() == CANCELLED)
-            throw new IgniteFutureCancelledException("Future was cancelled: " 
+ this);
+            throw new InternalFutureCancelledException("Future was cancelled: 
" + this);
 
         if (err != null)
             throw U.cast(err);
@@ -202,21 +202,21 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
 
     /** {@inheritDoc} */
     @SuppressWarnings({"unchecked", "TooBroadScope"})
-    @Override public void listenAsync(@Nullable final IgniteInClosure<? super 
IgniteFuture<R>> lsnr) {
+    @Override public void listenAsync(@Nullable final IgniteInClosure<? super 
InternalFuture<R>> lsnr) {
         if (lsnr != null) {
             checkValid();
 
             boolean done;
 
-            IgniteInClosure<? super IgniteFuture<R>> lsnr0 = lsnr;
+            IgniteInClosure<? super InternalFuture<R>> lsnr0 = lsnr;
 
             done = isDone();
 
             if (!done) {
-                lsnr0 = new IgniteInClosure<IgniteFuture<R>>() {
+                lsnr0 = new IgniteInClosure<InternalFuture<R>>() {
                     private final AtomicBoolean called = new AtomicBoolean();
 
-                    @Override public void apply(IgniteFuture<R> t) {
+                    @Override public void apply(InternalFuture<R> t) {
                         if (called.compareAndSet(false, true))
                             lsnr.apply(t);
                     }
@@ -241,15 +241,15 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
     }
 
     /** {@inheritDoc} */
-    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super 
IgniteFuture<R>>... lsnr) {
+    @Override public void stopListenAsync(@Nullable IgniteInClosure<? super 
InternalFuture<R>>... lsnr) {
         if (lsnr == null || lsnr.length == 0)
             lsnrs.clear();
         else {
             // Iterate through the whole list, removing all occurrences, if 
any.
-            for (Iterator<IgniteInClosure<? super IgniteFuture<R>>> it = 
lsnrs.iterator(); it.hasNext(); ) {
-                IgniteInClosure<? super IgniteFuture<R>> l1 = it.next();
+            for (Iterator<IgniteInClosure<? super InternalFuture<R>>> it = 
lsnrs.iterator(); it.hasNext(); ) {
+                IgniteInClosure<? super InternalFuture<R>> l1 = it.next();
 
-                for (IgniteInClosure<? super IgniteFuture<R>> l2 : lsnr)
+                for (IgniteInClosure<? super InternalFuture<R>> l2 : lsnr)
                     // Must be l1.equals(l2), not l2.equals(l1), because of 
the way listeners are added.
                     if (l1.equals(l2))
                         it.remove();
@@ -258,15 +258,15 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
     }
 
     /** {@inheritDoc} */
-    @Override public <T> IgniteFuture<T> chain(final IgniteClosure<? super 
IgniteFuture<R>, T> doneCb) {
+    @Override public <T> InternalFuture<T> chain(final IgniteClosure<? super 
InternalFuture<R>, T> doneCb) {
         final GridFutureAdapterEx<T> fut = new GridFutureAdapterEx<T>() {
             @Override public String toString() {
                 return "ChainFuture[orig=" + GridFutureAdapterEx.this + ", 
doneCb=" + doneCb + ']';
             }
         };
 
-        listenAsync(new IgniteInClosure<IgniteFuture<R>>() {
-            @Override public void apply(IgniteFuture<R> t) {
+        listenAsync(new IgniteInClosure<InternalFuture<R>>() {
+            @Override public void apply(InternalFuture<R> t) {
                 try {
                     fut.onDone(doneCb.apply(t));
                 }
@@ -302,7 +302,7 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
         if (lsnrs.isEmptyx())
             return;
 
-        for (IgniteInClosure<? super IgniteFuture<R>> lsnr : lsnrs)
+        for (IgniteInClosure<? super InternalFuture<R>> lsnr : lsnrs)
             notifyListener(lsnr);
     }
 
@@ -311,7 +311,7 @@ public class GridFutureAdapterEx<R> extends 
AbstractQueuedSynchronizer implement
      *
      * @param lsnr Listener.
      */
-    private void notifyListener(IgniteInClosure<? super IgniteFuture<R>> lsnr) 
{
+    private void notifyListener(IgniteInClosure<? super InternalFuture<R>> 
lsnr) {
         assert lsnr != null;
 
         try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureChainListener.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureChainListener.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureChainListener.java
index 478645c..19c06fe 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureChainListener.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/future/GridFutureChainListener.java
@@ -17,7 +17,7 @@ import org.gridgain.grid.util.lang.*;
 /**
  * Future listener to fill chained future with converted result of the source 
future.
  */
-public class GridFutureChainListener<T, R> implements 
IgniteInClosure<IgniteFuture<T>> {
+public class GridFutureChainListener<T, R> implements 
IgniteInClosure<InternalFuture<T>> {
     /** */
     private static final long serialVersionUID = 0L;
 
@@ -28,7 +28,7 @@ public class GridFutureChainListener<T, R> implements 
IgniteInClosure<IgniteFutu
     private final GridFutureAdapter<R> fut;
 
     /** Done callback. */
-    private final IgniteClosure<? super IgniteFuture<T>, R> doneCb;
+    private final IgniteClosure<? super InternalFuture<T>, R> doneCb;
 
     /**
      * Constructs chain listener.
@@ -38,14 +38,14 @@ public class GridFutureChainListener<T, R> implements 
IgniteInClosure<IgniteFutu
      * @param doneCb Done callback.
      */
     public GridFutureChainListener(GridKernalContext ctx, GridFutureAdapter<R> 
fut,
-        IgniteClosure<? super IgniteFuture<T>, R> doneCb) {
+        IgniteClosure<? super InternalFuture<T>, R> doneCb) {
         this.ctx = ctx;
         this.fut = fut;
         this.doneCb = doneCb;
     }
 
     /** {@inheritDoc} */
-    @Override public void apply(IgniteFuture<T> t) {
+    @Override public void apply(InternalFuture<T> t) {
         try {
             fut.onDone(doneCb.apply(t));
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
index 97ffd0e..dc3f84d 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/ipc/shmem/GridIpcSharedMemoryServerEndpoint.java
@@ -313,7 +313,7 @@ public class GridIpcSharedMemoryServerEndpoint implements 
GridIpcServerEndpoint
             }
         } // while
 
-        throw new GridInterruptedException("Socket accept was interrupted.");
+        throw new InternalInterruptedException("Socket accept was 
interrupted.");
     }
 
     /**
@@ -424,7 +424,7 @@ public class GridIpcSharedMemoryServerEndpoint implements 
GridIpcServerEndpoint
             try {
                 U.join(gcWorker);
             }
-            catch (GridInterruptedException e) {
+            catch (InternalInterruptedException e) {
                 U.warn(log, "Interrupted when stopping GC worker.", e);
             }
             finally {
@@ -495,7 +495,7 @@ public class GridIpcSharedMemoryServerEndpoint implements 
GridIpcServerEndpoint
         }
 
         /** {@inheritDoc} */
-        @Override protected void body() throws InterruptedException, 
GridInterruptedException {
+        @Override protected void body() throws InterruptedException, 
InternalInterruptedException {
             if (log.isDebugEnabled())
                 log.debug("GC worker started.");
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/lang/GridFunc.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridFunc.java 
b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridFunc.java
index 3b31ecf..f966818 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridFunc.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridFunc.java
@@ -492,15 +492,15 @@ public class GridFunc {
     };
 
     /** */
-    private static final IgnitePredicate<IgniteFuture<?>> FINISHED_FUTURE = 
new IgnitePredicate<IgniteFuture<?>>() {
-        @Override public boolean apply(IgniteFuture<?> f) {
+    private static final IgnitePredicate<InternalFuture<?>> FINISHED_FUTURE = 
new IgnitePredicate<InternalFuture<?>>() {
+        @Override public boolean apply(InternalFuture<?> f) {
             return f.isDone();
         }
     };
 
     /** */
-    private static final IgnitePredicate<IgniteFuture<?>> UNFINISHED_FUTURE = 
new IgnitePredicate<IgniteFuture<?>>() {
-        @Override public boolean apply(IgniteFuture<?> f) {
+    private static final IgnitePredicate<InternalFuture<?>> UNFINISHED_FUTURE 
= new IgnitePredicate<InternalFuture<?>>() {
+        @Override public boolean apply(InternalFuture<?> f) {
             return !f.isDone();
         }
     };
@@ -2757,13 +2757,13 @@ public class GridFunc {
     }
 
     /**
-     * Converts given object with interface {@link 
org.apache.ignite.lang.IgniteFuture} into an object implementing {@link Future}.
+     * Converts given object with interface {@link InternalFuture} into an 
object implementing {@link Future}.
      *
      * @param fut Future to convert.
      * @param <T> Type of computation result.
      * @return Instance implementing {@link Future}.
      */
-    public static <T> Future<T> as(final IgniteFuture<T> fut) {
+    public static <T> Future<T> as(final InternalFuture<T> fut) {
         A.notNull(fut, "fut");
 
         return new GridSerializableFuture<T>() {
@@ -2792,10 +2792,10 @@ public class GridFunc {
                 try {
                     return fut.get();
                 }
-                catch (IgniteFutureCancelledException ignore) {
+                catch (InternalFutureCancelledException ignore) {
                     throw new CancellationException("The computation was 
cancelled.");
                 }
-                catch (GridInterruptedException ignore) {
+                catch (InternalInterruptedException ignore) {
                     throw new InterruptedException("The computation was 
interrupted.");
                 }
                 catch (IgniteCheckedException e) {
@@ -2808,13 +2808,13 @@ public class GridFunc {
                 try {
                     return fut.get(timeout, unit);
                 }
-                catch (IgniteFutureCancelledException ignore) {
+                catch (InternalFutureCancelledException ignore) {
                     throw new CancellationException("The computation was 
cancelled.");
                 }
-                catch (GridInterruptedException ignore) {
+                catch (InternalInterruptedException ignore) {
                     throw new InterruptedException("The computation was 
interrupted.");
                 }
-                catch (IgniteFutureTimeoutException e) {
+                catch (InternalFutureTimeoutException e) {
                     throw new TimeoutException("The computation timed out: " + 
e.getMessage());
                 }
                 catch (IgniteCheckedException e) {
@@ -2825,14 +2825,14 @@ public class GridFunc {
     }
 
     /**
-     * Gets closure that converts {@link org.apache.ignite.lang.IgniteFuture} 
to {@link Future}.
+     * Gets closure that converts {@link InternalFuture} to {@link Future}.
      *
      * @param <T> Type of future.
-     * @return Closure that converts {@link 
org.apache.ignite.lang.IgniteFuture} to {@link Future}.
+     * @return Closure that converts {@link InternalFuture} to {@link Future}.
      */
-    public static <T> IgniteClosure<IgniteFuture<T>, Future<T>> future() {
-        return new C1<IgniteFuture<T>, Future<T>>() {
-            @Override public Future<T> apply(IgniteFuture<T> fut) {
+    public static <T> IgniteClosure<InternalFuture<T>, Future<T>> future() {
+        return new C1<InternalFuture<T>, Future<T>>() {
+            @Override public Future<T> apply(InternalFuture<T> fut) {
                 return as(fut);
             }
         };
@@ -8579,7 +8579,7 @@ public class GridFunc {
      * @param futs Futures. If none provided - this method is no-op.
      * @throws IgniteCheckedException If any of the futures failed.
      */
-    public static <T> void awaitAll(@Nullable IgniteFuture<T>... futs) throws 
IgniteCheckedException {
+    public static <T> void awaitAll(@Nullable InternalFuture<T>... futs) 
throws IgniteCheckedException {
         if (!isEmpty(futs))
             awaitAll(asList(futs));
     }
@@ -8590,7 +8590,7 @@ public class GridFunc {
      * @param futs Futures. If none provided - this method is no-op.
      * @throws IgniteCheckedException If any of the futures failed.
      */
-    public static <T> void awaitAll(@Nullable Collection<IgniteFuture<T>> 
futs) throws IgniteCheckedException {
+    public static <T> void awaitAll(@Nullable Collection<InternalFuture<T>> 
futs) throws IgniteCheckedException {
         awaitAll(0, null, futs);
     }
 
@@ -8601,7 +8601,7 @@ public class GridFunc {
      * @param futs Futures. If none provided - this method is no-op.
      * @throws IgniteCheckedException If any of the futures failed.
      */
-    public static <T> void awaitAll(long timeout, @Nullable 
Collection<IgniteFuture<T>> futs) throws IgniteCheckedException {
+    public static <T> void awaitAll(long timeout, @Nullable 
Collection<InternalFuture<T>> futs) throws IgniteCheckedException {
         awaitAll(timeout, null, futs);
     }
 
@@ -8617,7 +8617,7 @@ public class GridFunc {
      * @throws IgniteCheckedException If any of the futures failed.
      */
     @Nullable public static <T, R> R awaitAll(long timeout, @Nullable 
IgniteReducer<T, R> rdc,
-        @Nullable Collection<IgniteFuture<T>> futs) throws 
IgniteCheckedException {
+        @Nullable Collection<InternalFuture<T>> futs) throws 
IgniteCheckedException {
         if (futs == null || futs.isEmpty())
             return null;
 
@@ -8630,14 +8630,14 @@ public class GridFunc {
         // Note that it is important to wait in the natural order of 
collection and
         // not via listen method, because caller may actually add to this 
collection
         // concurrently while this method is in progress.
-        for (IgniteFuture<T> fut : futs) {
+        for (InternalFuture<T> fut : futs) {
             T t;
 
             if (timeout > 0) {
                 long left = end - U.currentTimeMillis();
 
                 if (left <= 0 && !fut.isDone())
-                    throw new IgniteFutureTimeoutException("Timed out waiting 
for all futures: " + futs);
+                    throw new InternalFutureTimeoutException("Timed out 
waiting for all futures: " + futs);
 
                 if (fut.isDone() && left < 0)
                     left = 0;
@@ -8662,7 +8662,7 @@ public class GridFunc {
      * @param <T> Type of computation result.
      * @return Completed future.
      */
-    public static <T> IgniteFuture<T> awaitOne(IgniteFuture<T>... futs) {
+    public static <T> InternalFuture<T> awaitOne(InternalFuture<T>... futs) {
         return isEmpty(futs) ? new GridFinishedFutureEx<T>() : 
awaitOne(asList(futs));
     }
 
@@ -8673,22 +8673,22 @@ public class GridFunc {
      * @param <T> Type of computation result.
      * @return Completed future.
      */
-    public static <T> IgniteFuture<T> awaitOne(Iterable<IgniteFuture<T>> futs) 
{
+    public static <T> InternalFuture<T> awaitOne(Iterable<InternalFuture<T>> 
futs) {
         if (F.isEmpty(futs))
             return new GridFinishedFutureEx<>();
 
         final CountDownLatch latch = new CountDownLatch(1);
 
-        final AtomicReference<IgniteFuture<T>> t = new AtomicReference<>();
+        final AtomicReference<InternalFuture<T>> t = new AtomicReference<>();
 
-        IgniteInClosure<IgniteFuture<T>> c = null;
+        IgniteInClosure<InternalFuture<T>> c = null;
 
-        for (IgniteFuture<T> fut : futs) {
+        for (InternalFuture<T> fut : futs) {
             if (fut != null) {
                 if (!fut.isDone()) {
                     if (c == null) {
-                        c = new CI1<IgniteFuture<T>>() {
-                            @Override public void apply(IgniteFuture<T> fut) {
+                        c = new CI1<InternalFuture<T>>() {
+                            @Override public void apply(InternalFuture<T> fut) 
{
                                 if (t.compareAndSet(null, fut))
                                     latch.countDown();
                             }
@@ -8720,7 +8720,7 @@ public class GridFunc {
         if (interrupted)
             Thread.currentThread().interrupt();
 
-        IgniteFuture<T> f = t.get();
+        InternalFuture<T> f = t.get();
 
         assert f != null;
 
@@ -8732,7 +8732,7 @@ public class GridFunc {
      *
      * @return Predicate for filtering finished futures.
      */
-    public static IgnitePredicate<IgniteFuture<?>> finishedFutures() {
+    public static IgnitePredicate<InternalFuture<?>> finishedFutures() {
         return FINISHED_FUTURE;
     }
 
@@ -8741,7 +8741,7 @@ public class GridFunc {
      *
      * @return Predicate for filtering unfinished futures.
      */
-    public static IgnitePredicate<IgniteFuture<?>> unfinishedFutures() {
+    public static IgnitePredicate<InternalFuture<?>> unfinishedFutures() {
         return UNFINISHED_FUTURE;
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFuture.java 
b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFuture.java
index 577d15d..e7c8fa9 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFuture.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFuture.java
@@ -10,6 +10,7 @@
 package org.gridgain.grid.util.lang;
 
 import org.apache.ignite.*;
+import org.apache.ignite.lang.*;
 
 import java.util.concurrent.*;
 
@@ -32,7 +33,7 @@ public interface GridPlainFuture<R> {
      * @param unit Timeout interval unit to wait future completes.
      * @return Completed future result.
      * @throws IgniteCheckedException In case of error.
-     * @throws org.apache.ignite.lang.IgniteFutureTimeoutException If timed 
out before future finishes.
+     * @throws InternalFutureTimeoutException If timed out before future 
finishes.
      */
     public R get(long timeout, TimeUnit unit) throws IgniteCheckedException;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFutureAdapter.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFutureAdapter.java
 
b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFutureAdapter.java
index 9ff1f99..51c31ae 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFutureAdapter.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/lang/GridPlainFutureAdapter.java
@@ -82,7 +82,7 @@ public class GridPlainFutureAdapter<R> implements 
GridPlainFuture<R> {
 
         try {
             if (doneLatch.getCount() > 0 && !doneLatch.await(timeout, unit))
-                throw new IgniteFutureTimeoutException("Failed to get future 
result due to waiting timed out.");
+                throw new InternalFutureTimeoutException("Failed to get future 
result due to waiting timed out.");
         }
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java 
b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
index 19de132..e650eff 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFuture.java
@@ -18,7 +18,7 @@ import java.io.*;
 import java.util.concurrent.*;
 
 /**
- * Reduced variant of {@link org.apache.ignite.lang.IgniteFuture} interface. 
Removed asynchronous
+ * Reduced variant of {@link InternalFuture} interface. Removed asynchronous
  * listen methods which require a valid grid kernal context.
  * @param <R> Type of the result for the future.
  */
@@ -28,8 +28,8 @@ public interface GridNioFuture<R> {
      * returns operation result.
      *
      * @return Operation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} 
thrown if the wait was interrupted.
-     * @throws IgniteFutureCancelledException Subclass of {@link 
GridException} throws if operation was cancelled.
+     * @throws InternalInterruptedException Subclass of {@link GridException} 
thrown if the wait was interrupted.
+     * @throws InternalFutureCancelledException Subclass of {@link 
GridException} throws if operation was cancelled.
      * @throws IgniteCheckedException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
      */
@@ -42,9 +42,9 @@ public interface GridNioFuture<R> {
      *
      * @param timeout The maximum time to wait in milliseconds.
      * @return Operation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} 
thrown if the wait was interrupted.
-     * @throws IgniteFutureTimeoutException Subclass of {@link GridException} 
thrown if the wait was timed out.
-     * @throws IgniteFutureCancelledException Subclass of {@link 
GridException} throws if operation was cancelled.
+     * @throws InternalInterruptedException Subclass of {@link GridException} 
thrown if the wait was interrupted.
+     * @throws InternalFutureTimeoutException Subclass of {@link 
GridException} thrown if the wait was timed out.
+     * @throws InternalFutureCancelledException Subclass of {@link 
GridException} throws if operation was cancelled.
      * @throws IgniteCheckedException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
      */
@@ -57,9 +57,9 @@ public interface GridNioFuture<R> {
      * @param timeout The maximum time to wait.
      * @param unit The time unit of the {@code timeout} argument.
      * @return Operation result.
-     * @throws GridInterruptedException Subclass of {@link GridException} 
thrown if the wait was interrupted.
-     * @throws IgniteFutureTimeoutException Subclass of {@link GridException} 
thrown if the wait was timed out.
-     * @throws IgniteFutureCancelledException Subclass of {@link 
GridException} throws if operation was cancelled.
+     * @throws InternalInterruptedException Subclass of {@link GridException} 
thrown if the wait was interrupted.
+     * @throws InternalFutureTimeoutException Subclass of {@link 
GridException} thrown if the wait was timed out.
+     * @throws InternalFutureCancelledException Subclass of {@link 
GridException} throws if operation was cancelled.
      * @throws IgniteCheckedException If operation failed.
      * @throws IOException If IOException occurred while performing operation.
      */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java 
b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
index ee84796..29b8311 100644
--- 
a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
+++ 
b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioFutureImpl.java
@@ -80,7 +80,7 @@ public class GridNioFutureImpl<R> extends 
AbstractQueuedSynchronizer implements
                 acquireSharedInterruptibly(0);
 
             if (getState() == CANCELLED)
-                throw new IgniteFutureCancelledException("Future was 
cancelled: " + this);
+                throw new InternalFutureCancelledException("Future was 
cancelled: " + this);
 
             if (err != null)
                 throw U.cast(err);
@@ -90,7 +90,7 @@ public class GridNioFutureImpl<R> extends 
AbstractQueuedSynchronizer implements
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
 
-            throw new GridInterruptedException(e);
+            throw new InternalInterruptedException(e);
         }
     }
 
@@ -111,7 +111,7 @@ public class GridNioFutureImpl<R> extends 
AbstractQueuedSynchronizer implements
         catch (InterruptedException e) {
             Thread.currentThread().interrupt();
 
-            throw new GridInterruptedException("Got interrupted while waiting 
for future to complete.", e);
+            throw new InternalInterruptedException("Got interrupted while 
waiting for future to complete.", e);
         }
     }
 
@@ -119,15 +119,15 @@ public class GridNioFutureImpl<R> extends 
AbstractQueuedSynchronizer implements
      * @param nanosTimeout Timeout (nanoseconds).
      * @return Result.
      * @throws InterruptedException If interrupted.
-     * @throws IgniteFutureTimeoutException If timeout reached before 
computation completed.
+     * @throws InternalFutureTimeoutException If timeout reached before 
computation completed.
      * @throws IgniteCheckedException If error occurred.
      */
     @Nullable protected R get0(long nanosTimeout) throws InterruptedException, 
IgniteCheckedException {
         if (endTime == 0 && !tryAcquireSharedNanos(0, nanosTimeout))
-            throw new IgniteFutureTimeoutException("Timeout was reached before 
computation completed.");
+            throw new InternalFutureTimeoutException("Timeout was reached 
before computation completed.");
 
         if (getState() == CANCELLED)
-            throw new IgniteFutureCancelledException("Future was cancelled: " 
+ this);
+            throw new InternalFutureCancelledException("Future was cancelled: 
" + this);
 
         if (err != null)
             throw U.cast(err);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java 
b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
index b0279ef..45d4b5b 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/nio/GridNioServer.java
@@ -711,7 +711,7 @@ public class GridNioServer<T> {
                     try {
                         U.sleep(50);
                     }
-                    catch (GridInterruptedException e) {
+                    catch (InternalInterruptedException e) {
                         throw new IOException("Thread has been interrupted.", 
e);
                     }
                 }
@@ -935,7 +935,7 @@ public class GridNioServer<T> {
                         try {
                             U.sleep(50);
                         }
-                        catch (GridInterruptedException e) {
+                        catch (InternalInterruptedException e) {
                             throw new IOException("Thread has been 
interrupted.", e);
                         }
                     }
@@ -1069,7 +1069,7 @@ public class GridNioServer<T> {
                     try {
                         U.sleep(50);
                     }
-                    catch (GridInterruptedException e) {
+                    catch (InternalInterruptedException e) {
                         throw new IOException("Thread has been interrupted.", 
e);
                     }
                 }
@@ -1117,7 +1117,7 @@ public class GridNioServer<T> {
         }
 
         /** {@inheritDoc} */
-        @Override protected void body() throws InterruptedException, 
GridInterruptedException {
+        @Override protected void body() throws InterruptedException, 
InternalInterruptedException {
             try {
                 boolean reset = false;
                 while (!closed) {
@@ -1577,7 +1577,7 @@ public class GridNioServer<T> {
         }
 
         /** {@inheritDoc} */
-        @Override protected void body() throws InterruptedException, 
GridInterruptedException {
+        @Override protected void body() throws InterruptedException, 
InternalInterruptedException {
             try {
                 boolean reset = false;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/typedef/X.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/util/typedef/X.java 
b/modules/core/src/main/java/org/gridgain/grid/util/typedef/X.java
index 29c5622..16849b5 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/typedef/X.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/typedef/X.java
@@ -11,7 +11,6 @@ package org.gridgain.grid.util.typedef;
 
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
@@ -814,11 +813,11 @@ public final class X {
      * @param futs Futures to wait for.
      * @throws IgniteCheckedException If any of the futures threw exception.
      */
-    public static void waitAll(@Nullable Iterable<IgniteFuture<?>> futs) 
throws IgniteCheckedException {
+    public static void waitAll(@Nullable Iterable<InternalFuture<?>> futs) 
throws IgniteCheckedException {
         if (F.isEmpty(futs))
             return;
 
-        for (IgniteFuture fut : futs)
+        for (InternalFuture fut : futs)
             fut.get();
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/checkpoint/sharedfs/GridSharedFsCheckpointSpiMultiThreadedSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/checkpoint/sharedfs/GridSharedFsCheckpointSpiMultiThreadedSelfTest.java
index 351eac2..b25d432 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/checkpoint/sharedfs/GridSharedFsCheckpointSpiMultiThreadedSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/checkpoint/sharedfs/GridSharedFsCheckpointSpiMultiThreadedSelfTest.java
@@ -58,7 +58,7 @@ public class GridSharedFsCheckpointSpiMultiThreadedSelfTest 
extends
 
         final AtomicBoolean fail = new AtomicBoolean();
 
-        IgniteFuture fut1 = GridTestUtils.runMultiThreadedAsync(
+        InternalFuture fut1 = GridTestUtils.runMultiThreadedAsync(
             new Callable<Object>() {
                 @Nullable @Override public Object call() throws Exception {
                     try {
@@ -78,7 +78,7 @@ public class GridSharedFsCheckpointSpiMultiThreadedSelfTest 
extends
             "writer-1"
         );
 
-        IgniteFuture fut2 = GridTestUtils.runMultiThreadedAsync(
+        InternalFuture fut2 = GridTestUtils.runMultiThreadedAsync(
             new Callable<Object>() {
                 @Nullable @Override public Object call() throws Exception {
                     try{
@@ -98,7 +98,7 @@ public class GridSharedFsCheckpointSpiMultiThreadedSelfTest 
extends
             "writer-2"
         );
 
-        IgniteFuture fut3 = GridTestUtils.runMultiThreadedAsync(
+        InternalFuture fut3 = GridTestUtils.runMultiThreadedAsync(
             new Callable<Object>() {
                 @Nullable @Override public Object call() throws Exception {
                     while (writeFinished.get() < THREAD_CNT * 2) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
index 7817c02..a4e9ddd 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/collision/GridTestCollisionTaskSession.java
@@ -189,7 +189,7 @@ public class GridTestCollisionTaskSession implements 
ComputeTaskSession {
     }
 
     /** {@inheritDoc} */
-    @Override public IgniteFuture<?> mapFuture() {
+    @Override public InternalFuture<?> mapFuture() {
         assert false : "Not implemented";
 
         return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
index 3684f5e..31fd843 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
@@ -100,7 +100,7 @@ public class GridOrderedMessageCancelSelfTest extends 
GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testTask() throws Exception {
-        ComputeTaskFuture<?> fut = executeAsync(compute(grid(0).forRemotes()), 
Task.class, null);
+        InternalComputeTaskFuture<?> fut = 
executeAsync(compute(grid(0).forRemotes()), Task.class, null);
 
         testMessageSet(fut);
     }
@@ -109,7 +109,7 @@ public class GridOrderedMessageCancelSelfTest extends 
GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testTaskException() throws Exception {
-        ComputeTaskFuture<?> fut = executeAsync(compute(grid(0).forRemotes()), 
FailTask.class, null);
+        InternalComputeTaskFuture<?> fut = 
executeAsync(compute(grid(0).forRemotes()), FailTask.class, null);
 
         testMessageSet(fut);
     }
@@ -118,7 +118,7 @@ public class GridOrderedMessageCancelSelfTest extends 
GridCommonAbstractTest {
      * @param fut Future to cancel.
      * @throws Exception If failed.
      */
-    private void testMessageSet(IgniteFuture<?> fut) throws Exception {
+    private void testMessageSet(InternalFuture<?> fut) throws Exception {
         cancelLatch.await();
 
         assertTrue(fut.cancel());

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiConcurrentConnectSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiConcurrentConnectSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiConcurrentConnectSelfTest.java
index 8a28058..3314076 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiConcurrentConnectSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiConcurrentConnectSelfTest.java
@@ -166,7 +166,7 @@ public class 
GridTcpCommunicationSpiConcurrentConnectSelfTest<T extends Communic
 
         final AtomicBoolean stop = new AtomicBoolean();
 
-        IgniteFuture<?> loadFut = null;
+        InternalFuture<?> loadFut = null;
 
         if (load) {
             loadFut = GridTestUtils.runMultiThreadedAsync(new Callable<Long>() 
{

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiLanTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiLanTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiLanTest.java
index ff15986..0f1b46c 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiLanTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiLanTest.java
@@ -157,7 +157,7 @@ public class GridTcpCommunicationSpiLanTest extends 
GridSpiAbstractTest<TcpCommu
 
         long start = System.currentTimeMillis();
 
-        IgniteFuture<?> fut = multithreadedAsync(new Runnable() {
+        InternalFuture<?> fut = multithreadedAsync(new Runnable() {
             @Override public void run() {
                 try {
                     while (cntr.getAndIncrement() < msgCnt) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
index 1889cd2..4ae5b5d 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiMultithreadedSelfTest.java
@@ -165,7 +165,7 @@ public abstract class 
GridTcpCommunicationSpiMultithreadedSelfTest extends GridS
 
         long start = System.currentTimeMillis();
 
-        IgniteFuture<?> fut = multithreadedAsync(new Runnable() {
+        InternalFuture<?> fut = multithreadedAsync(new Runnable() {
             /** Randomizer. */
             private Random rnd = new Random();
 
@@ -262,7 +262,7 @@ public abstract class 
GridTcpCommunicationSpiMultithreadedSelfTest extends GridS
 
         final int interval = 50;
 
-        IgniteFuture<?> fut = multithreadedAsync(new Runnable() {
+        InternalFuture<?> fut = multithreadedAsync(new Runnable() {
             /** {@inheritDoc} */
             @Override public void run() {
                 try {
@@ -301,7 +301,7 @@ public abstract class 
GridTcpCommunicationSpiMultithreadedSelfTest extends GridS
 
         final AtomicBoolean run = new AtomicBoolean(true);
 
-        IgniteFuture<?> fut2 = multithreadedAsync(new Runnable() {
+        InternalFuture<?> fut2 = multithreadedAsync(new Runnable() {
             @Override public void run() {
                 try {
                     while (run.get() && 
!Thread.currentThread().isInterrupted()) {
@@ -310,7 +310,7 @@ public abstract class 
GridTcpCommunicationSpiMultithreadedSelfTest extends GridS
                         
((TcpCommunicationSpi)spis.get(from.id())).onNodeLeft(to.id());
                     }
                 }
-                catch (GridInterruptedException ignored) {
+                catch (InternalInterruptedException ignored) {
                     Thread.currentThread().interrupt();
                 }
             }
@@ -361,7 +361,7 @@ public abstract class 
GridTcpCommunicationSpiMultithreadedSelfTest extends GridS
 
         long start = System.currentTimeMillis();
 
-        IgniteFuture<?> fut = multithreadedAsync(new Runnable() {
+        InternalFuture<?> fut = multithreadedAsync(new Runnable() {
             @Override public void run() {
                 try {
                     ClusterNode from = nodes.get(0);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiRecoverySelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiRecoverySelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiRecoverySelfTest.java
index fadac25..bb2d5b4 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiRecoverySelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/communication/tcp/GridTcpCommunicationSpiRecoverySelfTest.java
@@ -273,7 +273,7 @@ public class GridTcpCommunicationSpiRecoverySelfTest<T 
extends CommunicationSpi>
 
                     ses1.pauseReads().get();
 
-                    IgniteFuture<?> sndFut = GridTestUtils.runAsync(new 
Callable<Void>() {
+                    InternalFuture<?> sndFut = GridTestUtils.runAsync(new 
Callable<Void>() {
                         @Override public Void call() throws Exception {
                             for (int i = 0; i < 5000; i++) {
                                 spi0.sendMessage(node1, new 
GridTestMessage(node0.id(), msgId.incrementAndGet(), 0));
@@ -383,7 +383,7 @@ public class GridTcpCommunicationSpiRecoverySelfTest<T 
extends CommunicationSpi>
 
                     ses1.pauseReads().get();
 
-                    IgniteFuture<?> sndFut = GridTestUtils.runAsync(new 
Callable<Void>() {
+                    InternalFuture<?> sndFut = GridTestUtils.runAsync(new 
Callable<Void>() {
                         @Override public Void call() throws Exception {
                             for (int i = 0; i < 5000; i++) {
                                 spi0.sendMessage(node1, new 
GridTestMessage(node0.id(), msgId.incrementAndGet(), 0));
@@ -500,7 +500,7 @@ public class GridTcpCommunicationSpiRecoverySelfTest<T 
extends CommunicationSpi>
 
                     ses1.pauseReads().get();
 
-                    IgniteFuture<?> sndFut = GridTestUtils.runAsync(new 
Callable<Void>() {
+                    InternalFuture<?> sndFut = GridTestUtils.runAsync(new 
Callable<Void>() {
                         @Override public Void call() throws Exception {
                             for (int i = 0; i < 5000; i++) {
                                 spi0.sendMessage(node1, new 
GridTestMessage(node0.id(), msgId.incrementAndGet(), 0));

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/spi/discovery/tcp/GridTcpDiscoveryMultiThreadedTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/discovery/tcp/GridTcpDiscoveryMultiThreadedTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/discovery/tcp/GridTcpDiscoveryMultiThreadedTest.java
index e791cd1..24331ce 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/discovery/tcp/GridTcpDiscoveryMultiThreadedTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/discovery/tcp/GridTcpDiscoveryMultiThreadedTest.java
@@ -146,7 +146,7 @@ public class GridTcpDiscoveryMultiThreadedTest extends 
GridCommonAbstractTest {
 
         final AtomicInteger clientIdx = new AtomicInteger(GRID_CNT);
 
-        IgniteFuture<?> fut1 = multithreadedAsync(
+        InternalFuture<?> fut1 = multithreadedAsync(
             new Callable<Object>() {
                 @Override public Object call() throws Exception {
                     clientFlagPerThread.set(true);
@@ -169,7 +169,7 @@ public class GridTcpDiscoveryMultiThreadedTest extends 
GridCommonAbstractTest {
         for (int i = 0; i < GRID_CNT; i++)
             srvIdx.add(i);
 
-        IgniteFuture<?> fut2 = multithreadedAsync(
+        InternalFuture<?> fut2 = multithreadedAsync(
             new Callable<Object>() {
                 @Override public Object call() throws Exception {
                     clientFlagPerThread.set(false);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/spi/swapspace/file/GridFileSwapSpaceSpiSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/spi/swapspace/file/GridFileSwapSpaceSpiSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/spi/swapspace/file/GridFileSwapSpaceSpiSelfTest.java
index 566759e..4d0537e 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/spi/swapspace/file/GridFileSwapSpaceSpiSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/spi/swapspace/file/GridFileSwapSpaceSpiSelfTest.java
@@ -49,7 +49,7 @@ public class GridFileSwapSpaceSpiSelfTest extends 
GridSwapSpaceSpiAbstractSelfTe
 
         final AtomicBoolean done = new AtomicBoolean();
 
-        IgniteFuture<?> wFut = multithreadedAsync(new Callable<Object>() {
+        InternalFuture<?> wFut = multithreadedAsync(new Callable<Object>() {
             @Nullable @Override public Object call() throws Exception {
                 while (!done.get()) {
                     long val = valCntr.incrementAndGet();
@@ -66,7 +66,7 @@ public class GridFileSwapSpaceSpiSelfTest extends 
GridSwapSpaceSpiAbstractSelfTe
 
         wLatch.await();
 
-        IgniteFuture<?> rFut = multithreadedAsync(new Callable<Object>() {
+        InternalFuture<?> rFut = multithreadedAsync(new Callable<Object>() {
             @Nullable @Override public Object call() throws Exception {
                 while (valCntr.get() < 1000) {
                     byte[] val = spi.read(null, key, context());
@@ -131,7 +131,7 @@ public class GridFileSwapSpaceSpiSelfTest extends 
GridSwapSpaceSpiAbstractSelfTe
 
         final AtomicBoolean fin = new AtomicBoolean();
 
-        final IgniteFuture<?> fut = multithreadedAsync(new Callable<Object>() {
+        final InternalFuture<?> fut = multithreadedAsync(new 
Callable<Object>() {
             @Override public Object call() throws Exception {
                 Random rnd = new Random();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
index 2fdbe53..cf7f6c7 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/streamer/index/GridStreamerIndexSelfTest.java
@@ -289,7 +289,7 @@ public class GridStreamerIndexSelfTest extends 
GridCommonAbstractTest {
 
         win.start();
 
-        IgniteFuture<Long> pollFut = null;
+        InternalFuture<Long> pollFut = null;
 
         if (pollEvicted) {
             // These threads poll evicted events from the window if it doesn't 
break
@@ -312,7 +312,7 @@ public class GridStreamerIndexSelfTest extends 
GridCommonAbstractTest {
                                 U.sleep(50);
                         }
                     }
-                    catch (GridInterruptedException ignored) {
+                    catch (InternalInterruptedException ignored) {
                         // No-op.
                     }
                 }
@@ -324,7 +324,7 @@ public class GridStreamerIndexSelfTest extends 
GridCommonAbstractTest {
             // if it is still present in the window. In the tested index 
events are
             // sorted by value and the value is a number of repeated events, 
so, this
             // should be invariant.
-            IgniteFuture<Long> fut1 = runMultiThreadedAsync(new CAX() {
+            InternalFuture<Long> fut1 = runMultiThreadedAsync(new CAX() {
                 @Override public void applyx() throws IgniteCheckedException {
                     final String evt = Thread.currentThread().getName();
                     int cntr = 1;
@@ -351,7 +351,7 @@ public class GridStreamerIndexSelfTest extends 
GridCommonAbstractTest {
             }, threadCnt / 2, "test-multi");
 
             // This thread generates a set of single non-repeating events from 
0 to iters.
-            IgniteFuture<Long> fut2 = runMultiThreadedAsync(new CAX() {
+            InternalFuture<Long> fut2 = runMultiThreadedAsync(new CAX() {
                 @Override public void applyx() throws IgniteCheckedException {
                     for (int i = 0; i < iters && 
!Thread.currentThread().isInterrupted(); i++)
                         win.enqueue(String.valueOf(i));

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/streamer/window/GridStreamerWindowSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/apache/ignite/streamer/window/GridStreamerWindowSelfTest.java
 
b/modules/core/src/test/java/org/apache/ignite/streamer/window/GridStreamerWindowSelfTest.java
index bb8fbc6..2e3794b 100644
--- 
a/modules/core/src/test/java/org/apache/ignite/streamer/window/GridStreamerWindowSelfTest.java
+++ 
b/modules/core/src/test/java/org/apache/ignite/streamer/window/GridStreamerWindowSelfTest.java
@@ -784,7 +784,7 @@ public class GridStreamerWindowSelfTest extends 
GridCommonAbstractTest {
 
         final AtomicInteger added = new GridAtomicInteger();
 
-        IgniteFuture<?> fut = multithreadedAsync(new Callable<Object>() {
+        InternalFuture<?> fut = multithreadedAsync(new Callable<Object>() {
             @Override public Object call() throws Exception {
                 Random rnd = new Random();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/benchmarks/storevalbytes/GridCacheStoreValueBytesTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/benchmarks/storevalbytes/GridCacheStoreValueBytesTest.java
 
b/modules/core/src/test/java/org/gridgain/benchmarks/storevalbytes/GridCacheStoreValueBytesTest.java
index cbf6d61..ad843e0 100644
--- 
a/modules/core/src/test/java/org/gridgain/benchmarks/storevalbytes/GridCacheStoreValueBytesTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/benchmarks/storevalbytes/GridCacheStoreValueBytesTest.java
@@ -193,8 +193,8 @@ public class GridCacheStoreValueBytesTest {
 
         final Semaphore sem = new Semaphore(concurrentGetNum);
 
-        final IgniteInClosure<IgniteFuture> lsnr = new CI1<IgniteFuture>() {
-            @Override public void apply(IgniteFuture t) {
+        final IgniteInClosure<InternalFuture> lsnr = new CI1<InternalFuture>() 
{
+            @Override public void apply(InternalFuture t) {
                 sem.release();
             }
         };
@@ -223,7 +223,7 @@ public class GridCacheStoreValueBytesTest {
                             if (keys.size() == getKeyNum) {
                                 sem.acquire();
 
-                                IgniteFuture<Map<Integer, String>> f = 
cache.getAllAsync(keys);
+                                InternalFuture<Map<Integer, String>> f = 
cache.getAllAsync(keys);
 
                                 f.listenAsync(lsnr);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java 
b/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
index 6765221..bbbb964 100644
--- a/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
+++ b/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
@@ -205,7 +205,7 @@ public class GridTestTaskSession implements 
ComputeTaskSession {
     }
 
     /** {@inheritDoc} */
-    @Override public IgniteFuture<?> mapFuture() {
+    @Override public InternalFuture<?> mapFuture() {
         assert false : "Not implemented";
 
         return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java 
b/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java
index 1775505..3d89864 100644
--- a/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java
+++ b/modules/core/src/main/java/org/gridgain/grid/util/worker/GridWorker.java
@@ -136,7 +136,7 @@ public abstract class GridWorker implements Runnable {
 
             body();
         }
-        catch (GridInterruptedException e) {
+        catch (InternalInterruptedException e) {
             if (log.isDebugEnabled())
                 log.debug("Caught interrupted exception: " + e);
         }
@@ -185,9 +185,9 @@ public abstract class GridWorker implements Runnable {
      * The implementation should provide the execution body for this runnable.
      *
      * @throws InterruptedException Thrown in case of interruption.
      * @throws GridInterruptedException If interrupted.
      */
-    protected abstract void body() throws InterruptedException, 
GridInterruptedException;
+    protected abstract void body() throws InterruptedException, 
InternalInterruptedException;
 
     /**
      * Optional method that will be called after runnable is finished. Default

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/apache/ignite/spi/checkpoint/sharedfs/GridSharedFsCheckpointSpiMultiThreadedSelfTest.java
----------------------------------------------------------------------
@@ -185,9 +185,9 @@ public abstract class GridWorker implements Runnable {
      *
      * @throws InterruptedException Thrown in case of interruption.
-     * @throws GridInterruptedException If interrupted.
+     * @throws InternalInterruptedException If interrupted.
      */
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java
index f7d933a..e3dfa34 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java
@@ -40,7 +40,7 @@ public class GridCacheBalancingStoreSelfTest extends 
GridCommonAbstractTest {
 
         final AtomicBoolean finish = new AtomicBoolean();
 
-        IgniteFuture<Long> fut = GridTestUtils.runMultiThreadedAsync(new 
IgniteCallable<Void>() {
+        InternalFuture<Long> fut = GridTestUtils.runMultiThreadedAsync(new 
IgniteCallable<Void>() {
             @Override public Void call() throws Exception {
                 try {
                     ThreadLocalRandom rnd = ThreadLocalRandom.current();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java
index 17d9f42..36b13dc 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/cache/store/jdbc/GridCacheJdbcBlobStoreMultithreadedSelfTest.java
@@ -101,7 +101,7 @@ public class GridCacheJdbcBlobStoreMultithreadedSelfTest 
extends GridCommonAbstr
      * @throws Exception If failed.
      */
     public void testMultithreadedPut() throws Exception {
-        IgniteFuture<?> fut1 = runMultiThreadedAsync(new Callable<Object>() {
+        InternalFuture<?> fut1 = runMultiThreadedAsync(new Callable<Object>() {
             private final Random rnd = new Random();
 
             @Override public Object call() throws Exception {
@@ -115,7 +115,7 @@ public class GridCacheJdbcBlobStoreMultithreadedSelfTest 
extends GridCommonAbstr
             }
         }, 4, "put");
 
-        IgniteFuture<?> fut2 = runMultiThreadedAsync(new Callable<Object>() {
+        InternalFuture<?> fut2 = runMultiThreadedAsync(new Callable<Object>() {
             private final Random rnd = new Random();
 
             @Override public Object call() throws Exception {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
index c20926e..ba0ef37 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
@@ -13,7 +13,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.testframework.junits.common.*;
 import org.jetbrains.annotations.*;
 
@@ -58,7 +57,7 @@ public class GridCancelOnGridStopSelfTest extends 
GridCommonAbstractTest {
     /**
      * Cancelled task.
      */
-    private static final class CancelledTask extends 
ComputeTaskAdapter<String, Void> {
+    private static final class CancelledTask extends 
ComputeTaskFutureAdapter<String, Void> {
         /** */
         @IgniteLocalNodeIdResource
         private UUID locId;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
index e46813c..783c039 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
@@ -13,7 +13,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.discovery.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.ipfinder.vm.*;
 import org.gridgain.grid.util.typedef.*;
@@ -83,7 +82,7 @@ public class GridCancelUnusedJobSelfTest extends 
GridCommonAbstractTest {
 
         ignite.compute().localDeployTask(GridCancelTestTask.class, 
U.detectClassLoader(GridCancelTestTask.class));
 
-        ComputeTaskFuture<?> fut = executeAsync(ignite.compute(), 
GridCancelTestTask.class.getName(), null);
+        InternalComputeTaskFuture<?> fut = executeAsync(ignite.compute(), 
GridCancelTestTask.class.getName(), null);
 
         // Wait until jobs begin execution.
         boolean await = startSignal.await(WAIT_TIME, TimeUnit.MILLISECONDS);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
index afcf4ac..f10f8ef 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
 import org.apache.ignite.spi.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.spi.collision.*;
 import org.apache.ignite.spi.discovery.*;
 import org.apache.ignite.spi.discovery.tcp.*;
@@ -61,7 +60,7 @@ public class GridCancelledJobsMetricsSelfTest extends 
GridCommonAbstractTest {
     public void testCancelledJobs() throws Exception {
         final Ignite ignite = G.ignite(getTestGridName());
 
-        Collection<ComputeTaskFuture<?>> futs = new ArrayList<>();
+        Collection<InternalComputeTaskFuture<?>> futs = new ArrayList<>();
 
         IgniteCompute comp = ignite.compute().enableAsync();
 
@@ -80,7 +79,7 @@ public class GridCancelledJobsMetricsSelfTest extends 
GridCommonAbstractTest {
 
         colSpi.externalCollision();
 
-        for (ComputeTaskFuture<?> fut : futs) {
+        for (InternalComputeTaskFuture<?> fut : futs) {
             try {
                 fut.get();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
index 15ca5ff..17da6d8 100644
--- 
a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
+++ 
b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
@@ -13,7 +13,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.testframework.*;
 import org.gridgain.testframework.junits.common.*;
 
@@ -42,11 +41,11 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
 
             comp.execute(TestJobsChainTask.class, true);
 
-            ComputeTaskFuture<Integer> fut1 = comp.future();
+            InternalComputeTaskFuture<Integer> fut1 = comp.future();
 
             comp.execute(TestJobsChainTask.class, false);
 
-            ComputeTaskFuture<Integer> fut2 = comp.future();
+            InternalComputeTaskFuture<Integer> fut2 = comp.future();
 
             assert fut1.get() == 55;
             assert fut2.get() == 55;
@@ -72,11 +71,11 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
 
                         comp.execute(TestJobsChainTask.class, true);
 
-                        ComputeTaskFuture<Integer> fut1 = comp.future();
+                        InternalComputeTaskFuture<Integer> fut1 = 
comp.future();
 
                         comp.execute(TestJobsChainTask.class, false);
 
-                        ComputeTaskFuture<Integer> fut2 = comp.future();
+                        InternalComputeTaskFuture<Integer> fut2 = 
comp.future();
 
                         assert fut1.get() == 55;
                         assert fut2.get() == 55;
@@ -309,7 +308,7 @@ public class GridContinuousTaskSelfTest extends 
GridCommonAbstractTest {
 
     /** */
     @SuppressWarnings({"PublicInnerClass"})
-    public static class SlowMapTestTask extends ComputeTaskAdapter<Object, 
Integer> {
+    public static class SlowMapTestTask extends 
ComputeTaskFutureAdapter<Object, Integer> {
         /** */
         @IgniteTaskContinuousMapperResource
         private ComputeTaskContinuousMapper mapper;

Reply via email to